%% This file is part of the ANTOMEGA project version 0.7
%% -----------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%% Copyright (C) 2001 -- 2003 by Alexej Kryukov
%% Please report errors to: A.M. Kryukov <basileia@yandex.ru>

% the following corresponds to the encoding of the omlgc font,
% as described by Y. Haralambous in the file ridt-omega98.pdf.
% For symbols not existing in Unicode we always use codes for
% the same letter without accents.

\makesameletter{"0701}{"1FBD} % Greek coronis/psili

% alpha
\makesameletter{"0710}{"1F01} % dasia
\makesameletter{"0711}{"1F00} % psili
\makesameletter{"0712}{"1F71} % varia
\makesameletter{"0713}{"1F70} % oxia
\makesameletter{"0714}{"1FB6} % perispomeni
\makesameletter{"0715}{"1FB6} % circumflex
\makesameletter{"0716}{"1F03} % dasia and varia
\makesameletter{"0717}{"1F05} % dasia and oxia
\makesameletter{"0718}{"1F07} % dasia and perispomeni
\makesameletter{"0719}{"1F07} % dasia and circumflex
\makesameletter{"071A}{"1F02} % psili and varia
\makesameletter{"071B}{"1F04} % psili and oxia
\makesameletter{"071C}{"1F06} % psili and perispomeni
\makesameletter{"071D}{"1F06} % psili and circumflex
\makesameletter{"071E}{"1FB1} % macron
\makesameletter{"071F}{"1FB0} % vrachi

% alpha with ypogegrammeni
\makesameletter{"0720}{"1F81} % dasia
\makesameletter{"0721}{"1F80} % psili
\makesameletter{"0722}{"1FB2} % varia
\makesameletter{"0723}{"1FB4} % oxia
\makesameletter{"0724}{"1FB7} % perispomeni
\makesameletter{"0725}{"1FB7} % circumflex
\makesameletter{"0726}{"1F83} % dasia and varia
\makesameletter{"0727}{"1F85} % dasia and oxia
\makesameletter{"0728}{"1F87} % dasia and perispomeni
\makesameletter{"0729}{"1F87} % dasia and circumflex
\makesameletter{"072A}{"1F82} % psili and varia
\makesameletter{"072B}{"1F84} % psili and oxia
\makesameletter{"072C}{"1F86} % psili and perispomeni
\makesameletter{"072D}{"1F86} % psili and circumflex
\makesameletter{"072E}{"1FB1} % macron
\makesameletter{"072F}{"1FB0} % vrachi

% epsilon
\makesameletter{"0730}{"1F11} % dasia
\makesameletter{"0731}{"1F10} % psili
\makesameletter{"0732}{"1F72} % varia
\makesameletter{"0733}{"1F73} % oxia
\makesameletter{"0734}{"03B5} % perispomeni
\makesameletter{"0735}{"03B5} % circumflex
\makesameletter{"0736}{"1F13} % dasia and varia
\makesameletter{"0737}{"1F15} % dasia and oxia
\makesameletter{"0738}{"03B5} % dasia and perispomeni
\makesameletter{"0739}{"03B5} % dasia and circumflex
\makesameletter{"073A}{"1F12} % psili and varia
\makesameletter{"073B}{"1F14} % psili and oxia
\makesameletter{"073C}{"03B5} % psili and perispomeni
\makesameletter{"073D}{"03B5} % psili and circumflex
\makesameletter{"073E}{"03B5} % macron
\makesameletter{"073F}{"03B5} % vrachi

% eta
\makesameletter{"0740}{"1F21} % dasia
\makesameletter{"0741}{"1F20} % psili
\makesameletter{"0742}{"1F74} % varia
\makesameletter{"0743}{"1F75} % oxia
\makesameletter{"0744}{"1FC6} % perispomeni
\makesameletter{"0745}{"1FC6} % circumflex
\makesameletter{"0746}{"1F23} % dasia and varia
\makesameletter{"0747}{"1F25} % dasia and oxia
\makesameletter{"0748}{"1F27} % dasia and perispomeni
\makesameletter{"0749}{"1F27} % dasia and circumflex
\makesameletter{"074A}{"1F22} % psili and varia
\makesameletter{"074B}{"1F24} % psili and oxia
\makesameletter{"074C}{"1F26} % psili and perispomeni
\makesameletter{"074D}{"1F26} % psili and circumflex
\makesameletter{"074E}{"03B7} % macron
\makesameletter{"074F}{"03B7} % vrachi

% eta with ypogegrammeni
\makesameletter{"0750}{"1F91} % dasia
\makesameletter{"0751}{"1F90} % psili
\makesameletter{"0752}{"1FC2} % varia
\makesameletter{"0753}{"1FC4} % oxia
\makesameletter{"0754}{"1FC7} % perispomeni
\makesameletter{"0755}{"1FC7} % circumflex
\makesameletter{"0756}{"1F93} % dasia and varia
\makesameletter{"0757}{"1F95} % dasia and oxia
\makesameletter{"0758}{"1F97} % dasia and perispomeni
\makesameletter{"0759}{"1F97} % dasia and circumflex
\makesameletter{"075A}{"1F92} % psili and varia
\makesameletter{"075B}{"1F94} % psili and oxia
\makesameletter{"075C}{"1F96} % psili and perispomeni
\makesameletter{"075D}{"1F96} % psili and circumflex
\makesameletter{"075E}{"1FC3} % macron
\makesameletter{"075F}{"1FC3} % vrachi

% iota
\makesameletter{"0760}{"1F31} % dasia
\makesameletter{"0761}{"1F30} % psili
\makesameletter{"0762}{"1F76} % varia
\makesameletter{"0763}{"1F77} % oxia
\makesameletter{"0764}{"1FD6} % perispomeni
\makesameletter{"0765}{"1FD6} % circumflex
\makesameletter{"0766}{"1F33} % dasia and varia
\makesameletter{"0767}{"1F35} % dasia and oxia
\makesameletter{"0768}{"1F37} % dasia and perispomeni
\makesameletter{"0769}{"1F37} % dasia and circumflex
\makesameletter{"076A}{"1F32} % psili and varia
\makesameletter{"076B}{"1F34} % psili and oxia
\makesameletter{"076C}{"1F36} % psili and perispomeni
\makesameletter{"076D}{"1F36} % psili and circumflex
\makesameletter{"076E}{"1FD1} % macron
\makesameletter{"076F}{"1FD0} % vrachi

% omicron
\makesameletter{"0770}{"1F41} % dasia
\makesameletter{"0771}{"1F40} % psili
\makesameletter{"0772}{"1F71} % varia
\makesameletter{"0773}{"1F70} % oxia
\makesameletter{"0774}{"03BF} % perispomeni
\makesameletter{"0775}{"03BF} % circumflex
\makesameletter{"0776}{"1F43} % dasia and varia
\makesameletter{"0777}{"1F45} % dasia and oxia
\makesameletter{"0778}{"03BF} % dasia and perispomeni
\makesameletter{"0779}{"03BF} % dasia and circumflex
\makesameletter{"077A}{"1F42} % psili and varia
\makesameletter{"077B}{"1F44} % psili and oxia
\makesameletter{"077C}{"03BF} % psili and perispomeni
\makesameletter{"077D}{"03BF} % psili and circumflex
\makesameletter{"077E}{"03BF} % macron
\makesameletter{"077F}{"03BF} % vrachi

% upsilon
\makesameletter{"0780}{"1F51} % dasia
\makesameletter{"0781}{"1F50} % psili
\makesameletter{"0782}{"1F7A} % varia
\makesameletter{"0783}{"1F7B} % oxia
\makesameletter{"0784}{"1FE6} % perispomeni
\makesameletter{"0785}{"1FE6} % circumflex
\makesameletter{"0786}{"1F53} % dasia and varia
\makesameletter{"0787}{"1F55} % dasia and oxia
\makesameletter{"0788}{"1F57} % dasia and perispomeni
\makesameletter{"0789}{"1F57} % dasia and circumflex
\makesameletter{"078A}{"1F52} % psili and varia
\makesameletter{"078B}{"1F54} % psili and oxia
\makesameletter{"078C}{"1F56} % psili and perispomeni
\makesameletter{"078D}{"1F56} % psili and circumflex
\makesameletter{"078E}{"1FE1} % macron
\makesameletter{"078F}{"1FE0} % vrachi

% omega
\makesameletter{"0790}{"1F61} % dasia
\makesameletter{"0791}{"1F60} % psili
\makesameletter{"0792}{"1F7C} % varia
\makesameletter{"0793}{"1F7D} % oxia
\makesameletter{"0794}{"1FF6} % perispomeni
\makesameletter{"0795}{"1FF6} % circumflex
\makesameletter{"0796}{"1F63} % dasia and varia
\makesameletter{"0797}{"1F65} % dasia and oxia
\makesameletter{"0798}{"1F67} % dasia and perispomeni
\makesameletter{"0799}{"1F67} % dasia and circumflex
\makesameletter{"079A}{"1F62} % psili and varia
\makesameletter{"079B}{"1F64} % psili and oxia
\makesameletter{"079C}{"1F66} % psili and perispomeni
\makesameletter{"079D}{"1F66} % psili and circumflex
\makesameletter{"079E}{"03C9} % macron
\makesameletter{"079F}{"03C9} % vrachi

% omega with ypogegrammeni
\makesameletter{"07A0}{"1FA1} % dasia
\makesameletter{"07A1}{"1FA0} % psili
\makesameletter{"07A2}{"1FF2} % varia
\makesameletter{"07A3}{"1FF4} % oxia
\makesameletter{"07A4}{"1FF7} % perispomeni
\makesameletter{"07A5}{"1FF7} % circumflex
\makesameletter{"07A6}{"1FA3} % dasia and varia
\makesameletter{"07A7}{"1FA5} % dasia and oxia
\makesameletter{"07A8}{"1FA7} % dasia and perispomeni
\makesameletter{"07A9}{"1FA7} % dasia and circumflex
\makesameletter{"07AA}{"1FA2} % psili and varia
\makesameletter{"07AB}{"1FA4} % psili and oxia
\makesameletter{"07AC}{"1FA6} % psili and perispomeni
\makesameletter{"07AD}{"1FA6} % psili and circumflex
\makesameletter{"07AE}{"1FF3} % macron
\makesameletter{"07AF}{"1FF3} % vrachi

% macron
\makesameletter{"07B0}{"1FB9} % Alpha
\makesameletter{"07B1}{"0395} % Epsilon
\makesameletter{"07B2}{"0397} % Eta
\makesameletter{"07B3}{"1FD9} % Iota
\makesameletter{"07B4}{"039F} % Omicron
\makesameletter{"07B5}{"1FE9} % Upsilon
\makesameletter{"07B6}{"03A9} % Omega

% breve
\makesameletter{"07B8}{"1FB8} % Alpha
\makesameletter{"07B9}{"0395} % Epsilon
\makesameletter{"07BA}{"0397} % Eta
\makesameletter{"07BB}{"1FD8} % Iota
\makesameletter{"07BC}{"039F} % Omicron
\makesameletter{"07BD}{"1FE8} % Upsilon
\makesameletter{"07BE}{"03A9} % Omega

\makesameletter{"07C0}{"1FD2} % iota with dieresis and varia
\makesameletter{"07C1}{"1FD3} % iota with dieresis and oxia
\makesameletter{"07C2}{"1FD7} % iota with dieresis and perispomeni
\makesameletter{"07C3}{"1FD7} % iota with dieresis and circumflex
\makesameletter{"07C4}{"1FE2} % upsilon with dieresis and varia
\makesameletter{"07C5}{"1FE3} % upsilon with dieresis and oxia
\makesameletter{"07C6}{"1FE7} % upsilon with dieresis and perispomeni
\makesameletter{"07C7}{"1FE7} % upsilon with dieresis and circumflex
\makesameletter{"07C8}{"1FE5} % rho with dasia
\makesameletter{"07C9}{"1FE4} % rho with psili
\makesameletter{"07CA}{"1FE5} % alternate rho with dasia
\makesameletter{"07CB}{"1FE4} % alternate rho with psili
\makesameletter{"07CC}{"1FBE} % iota adscriptum
\makesameletter{"07CD}{"1FB3} % alpha with ypogegrammeni
\makesameletter{"07CE}{"1FC3} % eta with ypogegrammeni
\makesameletter{"07CF}{"1FF3} % omega with ypogegrammeni

\makesameletter{"07D0}{"1FBC} % Alpha with ypogegrammeni
\makesameletter{"07D1}{"1FBC} % Alpha with ypogegrammeni and macron
\makesameletter{"07D2}{"1FBC} % Alpha with ypogegrammeni and vrachy
\makesameletter{"07D3}{"1FCC} % Eta with ypogegrammeni
\makesameletter{"07D4}{"1FCC} % Eta with ypogegrammeni and macron
\makesameletter{"07D5}{"1FCC} % Eta with ypogegrammeni and vrachy
\makesameletter{"07D6}{"1FFC} % Omega with ypogegrammeni
\makesameletter{"07D7}{"1FFC} % Omega with ypogegrammeni and macron
\makesameletter{"07D8}{"1FFC} % Omega with ypogegrammeni and vrachy

\endinput

