%% This file is part of the ANTOMEGA project version 0.7
%% -----------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%% Copyright (C) 2001 -- 2003 by Alexej Kryukov
%% Please report errors to: A.M. Kryukov <basileia@yandex.ru>

% Russian alphabet

\makeletter{"0410}{"0430}
\makeletter{"0411}{"0431}
\makeletter{"0412}{"0432}
\makeletter{"0413}{"0433}
\makeletter{"0414}{"0434}
\makeletter{"0415}{"0435}
\makeletter{"0416}{"0436}
\makeletter{"0417}{"0437}
\makeletter{"0418}{"0438}
\makeletter{"0419}{"0439}
\makeletter{"041A}{"043A}
\makeletter{"041B}{"043B}
\makeletter{"041C}{"043C}
\makeletter{"041D}{"043D}
\makeletter{"041E}{"043E}
\makeletter{"041F}{"043F}
\makeletter{"0420}{"0440}
\makeletter{"0421}{"0441}
\makeletter{"0422}{"0442}
\makeletter{"0423}{"0443}
\makeletter{"0424}{"0444}
\makeletter{"0425}{"0445}
\makeletter{"0426}{"0446}
\makeletter{"0427}{"0447}
\makeletter{"0428}{"0448}
\makeletter{"0429}{"0449}
\makeletter{"042A}{"044A}
\makeletter{"042B}{"044B}
\makeletter{"042C}{"044C}
\makeletter{"042D}{"044D}
\makeletter{"042E}{"044E}
\makeletter{"042F}{"044F}

\makeletter{"0401}{"0451} % CYRYO

% Ukrainian, Belorussian, Serbian and Macedonian letters

\makeletter{"0402}{"0452}
\makeletter{"0403}{"0453}
\makeletter{"0404}{"0454}
\makeletter{"0405}{"0455}
\makeletter{"0406}{"0456}
\makeletter{"0407}{"0457}
\makeletter{"0408}{"0458}
\makeletter{"0409}{"0459}
\makeletter{"040A}{"045A}
\makeletter{"040B}{"045B}
\makeletter{"040C}{"045C}
\makeletter{"040E}{"045E}
\makeletter{"040F}{"045F}

\makeletter{"0490}{"0491} % CYRGUP

% Old Slavonic characters and Russian letters 
% used in the pre-1918 orthography

\makeletter{"0460}{"0461}
\makeletter{"0462}{"0463}
\makeletter{"0464}{"0465}
\makeletter{"0466}{"0467}
\makeletter{"0468}{"0469}
\makeletter{"046A}{"046B}
\makeletter{"046C}{"046D}
\makeletter{"046E}{"046F}
\makeletter{"0470}{"0471}
\makeletter{"0472}{"0473}
\makeletter{"0474}{"0475}
\makeletter{"0476}{"0477}
\makeletter{"0478}{"0479}
\makeletter{"047A}{"047B}
\makeletter{"047C}{"047D}
\makeletter{"047E}{"047F}
\makeletter{"0480}{"0481}

% Asian Cyrillic letters

\makeletter{"048A}{"048B}
\makeletter{"048C}{"048D}
\makeletter{"048E}{"048F}
\makeletter{"0490}{"0491}
\makeletter{"0492}{"0493}
\makeletter{"0494}{"0495}
\makeletter{"0496}{"0497}
\makeletter{"0498}{"0499}
\makeletter{"049A}{"049B}
\makeletter{"049C}{"049D}
\makeletter{"049E}{"049F}
\makeletter{"04A0}{"04A1}
\makeletter{"04A2}{"04A3}
\makeletter{"04A4}{"04A5}
\makeletter{"04A6}{"04A7}
\makeletter{"04A8}{"04A9}
\makeletter{"04AA}{"04AB}
\makeletter{"04AC}{"04AD}
\makeletter{"04AE}{"04AF}
\makeletter{"04B0}{"04B1}
\makeletter{"04B2}{"04B3}
\makeletter{"04B4}{"04B5}
\makeletter{"04B6}{"04B7}
\makeletter{"04B8}{"04B9}
\makeletter{"04BA}{"04BB}
\makeletter{"04BC}{"04BD}
\makeletter{"04BE}{"04BF}
\makeletter{"04C1}{"04C2}
\makeletter{"04C3}{"04C4}
\makeletter{"04C5}{"04C6}
\makeletter{"04C7}{"04C8}
\makeletter{"04C9}{"04CA}
\makeletter{"04CB}{"04CC}
\makeletter{"04CD}{"04CE}
\makeletter{"04D0}{"04D1}
\makeletter{"04D2}{"04D3}
\makeletter{"04D4}{"04D5}
\makeletter{"04D6}{"04D7}
\makeletter{"04D8}{"04D9}
\makeletter{"04DA}{"04DB}
\makeletter{"04DC}{"04DD}
\makeletter{"04DE}{"04DF}
\makeletter{"04E0}{"04E1}
\makeletter{"04E2}{"04E3}
\makeletter{"04E4}{"04E5}
\makeletter{"04E6}{"04E7}
\makeletter{"04E8}{"04E9}
\makeletter{"04EA}{"04EB}
\makeletter{"04EC}{"04ED}
\makeletter{"04EE}{"04EF}
\makeletter{"04F0}{"04F1}
\makeletter{"04F2}{"04F3}
\makeletter{"04F4}{"04F5}
\makeletter{"04F8}{"04F9}

\makeletter{"0400}{"0450}
\makeletter{"040D}{"045D}

\endinput
