%%
%% This is file `t2aenc-antomega.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% antenc.dtx  (with options: `T2A')
%% 
%% This file is a part of the ANTOMEGA project version 0.8
%% -----------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%% Copyright (C) 2001 -- 2005 by Alexej Kryukov
%% Please report errors to: A.M. Kryukov <basileia@yandex.ru>
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesFile{t2aenc-antomega.def}
  [2005/05/07 v0.8 Antomega encodings definition file]
\DeclareFontEncoding{T2A}{}{}
\def\ant@encoding{T2A}
\DeclareTextCommand{\`}{\ant@encoding}[1]{#1^^^^0300}
\DeclareTextCommand{\'}{\ant@encoding}[1]{#1^^^^0301}
\DeclareTextCommand{\^}{\ant@encoding}[1]{#1^^^^0302}
\DeclareTextCommand{\~}{\ant@encoding}[1]{#1^^^^0303}
\DeclareTextCommand{\"}{\ant@encoding}[1]{#1^^^^0308}
\DeclareTextCommand{\H}{\ant@encoding}[1]{#1^^^^030b}
\DeclareTextCommand{\r}{\ant@encoding}[1]{#1^^^^030a}
\DeclareTextCommand{\v}{\ant@encoding}[1]{#1^^^^030c}
\DeclareTextCommand{\u}{\ant@encoding}[1]{#1^^^^0306}
\DeclareTextCommand{\=}{\ant@encoding}[1]{#1^^^^0304}
\DeclareTextCommand{\.}{\ant@encoding}[1]{#1^^^^0307}
\DeclareTextCommand{\f}{\ant@encoding}[1]{#1^^^^0311}
\DeclareTextCommand{\C}{\ant@encoding}[1]{#1^^^^030f}
\DeclareTextCommand{\b}{\ant@encoding}[1]{#1^^^^0331}
\DeclareTextCommand{\c}{\ant@encoding}[1]{#1^^^^0327}
\DeclareTextCommand{\d}{\ant@encoding}[1]{#1^^^^0323}
\DeclareTextCommand{\k}{\ant@encoding}[1]{#1^^^^0328}
\DeclareTextAccent{\GraveAccent}{\ant@encoding}{0}
\DeclareTextAccent{\AcuteAccent}{\ant@encoding}{1}
\DeclareTextAccent{\CircumflexAccent}{\ant@encoding}{2}
\DeclareTextAccent{\TildeAccent}{\ant@encoding}{3}
\DeclareTextAccent{\DieresisAccent}{\ant@encoding}{4}
\DeclareTextAccent{\HungarumlautAccent}{\ant@encoding}{5}
\DeclareTextAccent{\RingAccent}{\ant@encoding}{6}
\DeclareTextAccent{\CaronAccent}{\ant@encoding}{7}
\DeclareTextAccent{\BreveAccent}{\ant@encoding}{8}
\DeclareTextAccent{\MacronAccent}{\ant@encoding}{9}
\DeclareTextAccent{\DotAboveAccent}{\ant@encoding}{10}
\DeclareTextCommand{\BarBelowAccent}{\ant@encoding}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\noocpchar{9}}\vss}\hidewidth}\egroup}
\DeclareTextCommand{\CedillaAccent}{\ant@encoding}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\hidewidth\noocpchar{11}\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\DotBelowAccent}{\ant@encoding}[1]
   {\hmode@bgroup
    \o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}\egroup}
\DeclareTextCommand{\OgonekAccent}{\ant@encoding}[1]
   {\oalign{\null#1\crcr\hidewidth\noocpchar{12}}}
\DeclareTextAccent{\CyrillicFlexAccent}{T2A}{18}
\DeclareTextAccent{\DoubleGraveAccent}{T2A}{19}
\DeclareTextAccent{\U}{T2A}{20}
\DeclareTextCommand{\textdollar}{\ant@encoding}{\noocpchar{"24}}
\DeclareTextCommand{\textgreater}{\ant@encoding}{\noocpchar{"3C}}
\DeclareTextCommand{\textless}{\ant@encoding}{\noocpchar{"3E}}
\DeclareTextCommand{\textbackslash}{\ant@encoding}{\noocpchar{"5C}}
\DeclareTextCommand{\textasciicircum}{\ant@encoding}{\noocpchar{"5E}}
\DeclareTextCommand{\textunderscore}{\ant@encoding}{\noocpchar{"5F}}
\DeclareTextCommand{\textasciigrave}{\ant@encoding}{\noocpchar{"60}}
\DeclareTextCommand{\textbraceleft}{\ant@encoding}{\noocpchar{"7B}}
\DeclareTextCommand{\textbar}{\ant@encoding}{\noocpchar{"7C}}
\DeclareTextCommand{\textbraceright}{\ant@encoding}{\noocpchar{"7D}}
\DeclareTextCommand{\textasciitilde}{\ant@encoding}{\noocpchar{"7E}}
\DeclareTextSymbol{\textsection}{\ant@encoding}{"00A7}
\DeclareTextSymbol{\guillemotleft}{\ant@encoding}{"00AB}
\DeclareTextSymbol{\guillemotright}{\ant@encoding}{"00BB}
\DeclareTextSymbol{\i}{\ant@encoding}{"0131}
\DeclareTextSymbol{\textcompwordmark}{\ant@encoding}{"200C}
\DeclareTextSymbol{\textendash}{\ant@encoding}{"2013}
\DeclareTextSymbol{\textemdash}{\ant@encoding}{"2014}
\DeclareTextSymbol{\textquoteleft}{\ant@encoding}{"2018}
\DeclareTextSymbol{\textquoteright}{\ant@encoding}{"2019}
\DeclareTextSymbol{\textquotedblleft}{\ant@encoding}{"201C}
\DeclareTextSymbol{\textquotedblright}{\ant@encoding}{"201D}
\DeclareTextSymbol{\quotedblbase}{\ant@encoding}{"201E}
\DeclareTextCommand{\textcircled}{\ant@encoding}[1]{{%
   \ooalign{%
      \hfil \raise .07ex\hbox {\upshape#1}\hfil \crcr
      \char 79   % '117 = "4F
   }%
}}
\DeclareTextSymbol{\textnumero}{\ant@encoding}{"2116}
\DeclareTextSymbol{\textlangle}{\ant@encoding}{"2329}
\DeclareTextSymbol{\textrangle}{\ant@encoding}{"232A}
\DeclareTextSymbol{\textvisiblespace}{\ant@encoding}{"2423}
\DeclareTextSymbol{\j}{\ant@encoding}{"F6BE}
\let\ant@encoding\@undefined
\endinput
%%
%% End of file `t2aenc-antomega.def'.
