%%
%% This is file `lgrenc-antomega.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% antenc.dtx  (with options: `LGR')
%% 
%% This file is a part of the ANTOMEGA project version 0.8
%% -----------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%% Copyright (C) 2001 -- 2005 by Alexej Kryukov
%% Please report errors to: A.M. Kryukov <basileia@yandex.ru>
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesFile{lgrenc-antomega.def}
  [2005/05/07 v0.8 Antomega encodings definition file]
\DeclareFontEncoding{LGR}{}{}
\def\ant@encoding{LGR}
\DeclareTextCommand{\`}{\ant@encoding}[1]{#1^^^^0300}
\DeclareTextCommand{\'}{\ant@encoding}[1]{#1^^^^0301}
\DeclareTextCommand{\"}{\ant@encoding}[1]{#1^^^^0308}
\DeclareTextCommand{\u}{\ant@encoding}[1]{#1^^^^0306}
\DeclareTextCommand{\=}{\ant@encoding}[1]{#1^^^^0304}
\DeclareTextAccent{\GraveAccent}{LGR}{`\`}
\DeclareTextAccent{\AcuteAccent}{LGR}{`\'}
\DeclareTextAccent{\BreveAccent}{LGR}{30}
\DeclareTextAccent{\MacronAccent}{LGR}{31}
\DeclareTextAccent{\GreekCircumflexAccent}{LGR}{`\~}
\DeclareTextSymbol{\guillemotleft}{\ant@encoding}{"00AB}
\DeclareTextSymbol{\guillemotright}{\ant@encoding}{"00BB}
\DeclareTextSymbol{\textcompwordmark}{\ant@encoding}{"200C}
\DeclareTextSymbol{\textperthousand}{\ant@encoding}{"2030}
\DeclareTextSymbol{\textendash}{\ant@encoding}{"2013}
\DeclareTextSymbol{\textemdash}{\ant@encoding}{"2014}
\DeclareTextSymbol{\textquoteleft}{\ant@encoding}{"2018}
\DeclareTextSymbol{\textquoteright}{\ant@encoding}{"2019}
\DeclareTextSymbol{\textquotedblleft}{\ant@encoding}{"201C}
\DeclareTextSymbol{\textquotedblright}{\ant@encoding}{"201D}
\DeclareTextSymbol{\texteuro}{\ant@encoding}{"20AC}
\DeclareTextCommand{\textcircled}{\ant@encoding}[1]{{%
   \ooalign{%
      \hfil \raise .07ex\hbox {\upshape#1}\hfil \crcr
      \char 79   % '117 = "4F
   }%
}}
\let\ant@encoding\@undefined
\endinput
%%
%% End of file `lgrenc-antomega.def'.
